import {
  getConfig,
  checkResponseForError,
  addToItemList,
} from "./util";

import {
    fetchWithAuth,
} from "./auth";

import {
  debounceScanner
} from "./scanner";

/*
 * Add items by delivery tag
 */
export async function addItemByTag(tag) {
  console.log("Trying to add item by tag:", tag);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/tag/" + tag);
  if (response.status == 200) {
    var delivery = await response.json();
    addToItemList(
      delivery.uuid, 
      `${ delivery.tag } (${ delivery.addressee }, ${ delivery.team })`, 
      document.querySelector("#storage_select").value, 
      checkinItem
    );
    document.getElementById("beep").play();
    console.log("Added item by tag");
    return true;
  } else if(response.status == 404) {
    console.log("Item not found");
  } else {
    checkResponseForError(response, "Failed to get item from backend");
  }
  return false;
}

/*
 * add items scanned from qrcode
 */
export async function addItemByScan(delivery_uuid) {
  debounceScanner();
  if (delivery_uuid.length == 36) {
    console.log("Trying to add item by uuid (scanned)");
    var config = await getConfig();
    var response = await fetchWithAuth(config.backend_url + "/delivery/" + delivery_uuid);
    if (response.status == 200) {
      var delivery = await response.json();
      addToItemList(
        delivery.uuid, 
        `${ delivery.tag } (${ delivery.addressee }, ${ delivery.team })`, 
        document.querySelector("#storage_select").value, 
        checkinItem
      );
      document.getElementById("beep").play();
      console.log("added item by uuid (scanned)");
    } else if(response.status == 404) {
      console.log("Item not found");
    } else {
      checkResponseForError(response, "Failed to get item from backend");
    }
  } else {
    alert("QR Code is not a bgp checkin code.");
  }
}

/*
 * Add Item without code with a image
 */

export async function addItemImage(e) {
  console.log("Adding item  by image");
  var form = new FormData();
  form.append("image", e.files[0]);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/item/register", {
    method: "POST",
    body: form
  });
  if(await checkResponseForError(response, "Failed to save item")) {
    var delivery = await response.json();
    addToItemList(
      delivery.uuid, 
      `${ delivery.tag } (${ delivery.addressee }, ${ delivery.team })`, 
      document.querySelector("#storage_select").value, 
      checkinItem
    );
    document.getElementById("beep").play();
    console.log("Added item by image.");
  }
}

/*
 * Checkin the item list
 */

export async function checkinItem() {
  var element= event.target.closest("div");
  var storage = element.querySelector(".storage").textContent;
  console.log("check in item for delivery", element.dataset.uuid, "at", storage);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/item", {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
    },
    body: JSON.stringify({
      "delivery_uuid": element.dataset.uuid,
      "storage_name": storage,
    })
  });
  if(await checkResponseForError(response, "Failed to checkin item " + element.dataset.uuid)) {
    element.classList.remove("alert-warning");
    element.classList.remove("alert-danger");
    element.classList.add("alert-success");
    await new Promise(r => setTimeout(r,2000));
    element.parentNode.remove();
  } else {
    element.classList.remove("alert-warning");
    element.classList.add("alert-danger");
  }
}
