import {
    ed448
} from "@noble/curves/ed448";

import {
    getConfig,
    checkResponseForError,
    addToItemList,
    htoa,
} from "./util";

import {
    fetchWithAuth,
} from "./auth";

import {
  debounceScanner
} from "./scanner";

/*
 * show delivery by tag
 */
export async function listItemsByTag(tag) {
  console.log("check tag", tag,event,event.target.value);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/tag/" + event.target.value);
  if (response.status == 200) {
    var delivery = await response.json();
    if (delivery.items.length == 0) {
      console.log("Delivery has no items arrived", delivery);
      alert("No items ready to checkout for delivery " + delivery.tag);
    } else {
      for (var i = 0; i < delivery.items.length; i++) {
        addToItemList(
          delivery.items[i].uuid,
          `${ delivery.tag } (${ delivery.addressee }, ${ delivery.team })`,
          delivery.items[i].storage_name,
          checkoutItem
        );
      }
      console.log("Added item by tag");
    }
    document.getElementById("beep").play();
    return true;
  } else if(response.status == 404) {
    console.log("Item not found");
  } else {
    checkResponseForError(response, "Failed to get delivery from backend");
  }
  return false;
}

/*
 * show delivery scanned from qrcode
 */
export async function listItemsByScan(qrcode) {
  debounceScanner();
  var delivery_uuid;
  var signature;
  console.log("got item",qrcode);
  [delivery_uuid, signature] = qrcode.split("/");
  console.log(delivery_uuid, signature);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/delivery/" + delivery_uuid);
  if (response.status == 200) {
    var delivery = await response.json();
    console.log("check valid qr code");
    if (ed448.verify(htoa(signature), new TextEncoder().encode(delivery_uuid), htoa(delivery.verification))) {
      for (var i = 0; i < delivery.items.length; i++) {
        addToItemList(
          delivery.items[i].uuid,
          `${ delivery.tag } (${ delivery.addressee }, ${ delivery.team })`,
          delivery.items[i].storage_name,
          checkoutItem
        );
      }
      document.getElementById("beep").play();
      console.log("Added item by scann");
    } else {
      alert("Could not verify signature.");
      console.log("Could not verify signature.");
    }
  } else {
    checkResponseForError(response, "Failed to get delivery from backend.");
  }
}

/*
 * show items by searching for delivery
 */
export function onSearchInputUpdate(a,b,c) {
  console.log("TODO: implement onSearchInputUpdate",a,b,c,event);

}
export function onSearchInputChanged(a,b,c) {
  console.log("TODO: implement onSearchInputChanged",a,b,c,event);
}
function listItemsBySearch(a,b,c) {
  console.log("search for items",a,b,c,event);
}

async function checkoutItem() {
  var element = event.target.closest("li").firstChild;
  var item_uuid = element.dataset.uuid;
  console.log("checkout item", item_uuid);
  var config = await getConfig();
  var response = await fetchWithAuth(config.backend_url + "/item/" + item_uuid,{
    method: "DELETE"
  });
  if (response.status == 200) {
    element.classList.remove("alert-warning");
    element.classList.remove("alert-danger");
    element.classList.add("alert-success");
    await new Promise(r => setTimeout(r,2000));
    element.parentNode.remove();
  } else {
    element.classList.remove("alert-warning");
    element.classList.add("alert-danger");
  }
}
