import {
    Buffer
} from "buffer";

export async function checkResponseForError(response, message) {
  if (response.status !== 200) {
    let content = await response.text();
    console.log("Got Response Error:", message, response);
    alert(message + "; Status: " + response.status + "; Content: " + content);
    return false;
  }
  return true;
}

var config;
export async function getConfig() {
  if (config == undefined) {
    var config_request = await fetch("config.json");
    console.log("Loading config");
    if(await checkResponseForError(config_request, "Could not load config")) {
      config = await config_request.json();
      console.log("Loaded config");
    }
  }
  return config;
}


export function htoa(h) {
  return Uint8Array.from(Buffer.from(h,"hex"));
}

export function toast(title, message) {
  var toastDiv = document.getElementById("bottomToast");
  toastDiv.children[0].children[0].innerHTML = title;
  toastDiv.children[1].innerHTML = message;
  toastDiv.classList.remove("hide");
  toastDiv.classList.add("show");
  toastDiv.classList.add("showing");
  setTimeout(function(){
    toastDiv.classList.remove("show");
    toastDiv.classList.remove("showing");
    toastDiv.classList.add("hide");
  }, 3000);
}

export function removeFromItemList() {
  event.target.closest("li").remove();
}

export function addToItemList(uuid, text, storage, onClick) {
  var items = document.querySelector("#items");
  var item = document.createElement("li");
  item.innerHTML = `<div data-uuid="${ uuid }" class="alert alert-warning" role="alert">${text}<strong class="ml-1">[<span class="storage">${ storage }</span>]</strong><button type="button" class="btn btn-primary ml-1"><i class="bi bi-send"></i></button><button type="button" class="btn btn-danger ml-1"><i class="bi bi-x-circle"></i></button></div>`;
  item.querySelectorAll("button")[0].onclick = onClick;
  item.querySelectorAll("button")[1].onclick = removeFromItemList;
  items.appendChild(item);
}
